teatime.plugins package
=======================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   teatime.plugins.eth1
   teatime.plugins.ipfs

Submodules
----------

teatime.plugins.base module
---------------------------

.. automodule:: teatime.plugins.base
   :members:
   :undoc-members:
   :show-inheritance:

teatime.plugins.context module
------------------------------

.. automodule:: teatime.plugins.context
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: teatime.plugins
   :members:
   :undoc-members:
   :show-inheritance:
